@@ -38,6 +38,20 @@ def add_define(name, value = nil)
     $defs.push("-D#{name}")
   end
 end
-
+require 'rubygems'
+unless Gem.win_platform? || RUBY_PLATFORM =~ /darwin/
+#  $LDFLAGS += " -lrt" # for clock_gettime
+end
 add_define("RUBY_VERSION", RUBY_VERSION.gsub('.', ''))
+
+# for ruby 1.9, determine whether threads inherit trace flags (latest 1.9.2 works correctly)
+if RUBY_VERSION > "1.9"
+  require 'set'
+  threads = Set.new
+  set_trace_func lambda { |*args| threads << Thread.current.object_id }
+  Thread.new{1}.join
+  set_trace_func nil
+  add_define("THREADS_INHERIT_EVENT_FLAGS", (threads.size == 2) ? "1" : "0")
+end
+
 create_makefile("ruby_prof")
