@@ -1,3 +1,4 @@
+
 module Rack
   class RubyProf
     def initialize(app)
@@ -13,13 +14,14 @@ module Rack
       result
     end
 
-    def print
-      printers = {::RubyProf::FlatPrinter => 'c:/temp/profile.txt',
-                  ::RubyProf::GraphHtmlPrinter => 'c:/temp/profile.html'}
+    def print(data)
+      require 'tmpdir' # late require so we load on demand only
+      printers = {::RubyProf::FlatPrinter => ::File.join(Dir.tmpdir, 'profile.txt'),
+                  ::RubyProf::GraphHtmlPrinter => ::File.join(Dir.tmpdir, 'profile.html')}
 
       printers.each do |printer_klass, file_name|
-        printer = printer_klass.new(result)
-          ::File.open(file_name, 'wb') do |file|
+        printer = printer_klass.new(data)
+        ::File.open(file_name, 'wb') do |file|
           printer.print(file, :min_percent => 0.00000001 )
         end
       end
